unit AddLineDlg;

interface

uses
  Winapi.Windows,
  Winapi.Messages,
  System.SysUtils,
  System.Variants,
  System.Classes,
  Vcl.Graphics,
  Vcl.Controls,
  Vcl.Forms,
  Vcl.Dialogs,
  Vcl.StdCtrls,

  Codec, StoreRoom, StoreLine, StoreUser,
  VaxLine,
  VaxDefine, VaxServerCOM, VaxServerSIP;


type TAddLineForm = class(TForm)

  Label1: TLabel;
  ComboLine: TComboBox;

  GroupBox1: TGroupBox;
  Label2: TLabel;
  Label4: TLabel;

  EditAuthPwd: TEdit;
  EditServerPort: TEdit;

  Label7: TLabel;
  Label8: TLabel;

  ListBoxEnableCodecs: TListBox;
  ListBoxDisableCodecs: TListBox;

  btnDisableCodec: TButton;
  btnEnableCodec: TButton;

  GroupBox2: TGroupBox;
  GroupBoxIncomingCall: TGroupBox;
  GroupBox4: TGroupBox;

  RadioRejectCall: TRadioButton;
  RadioConnectToLogin: TRadioButton;
  RadioConnectToRoom: TRadioButton;

  ComboConnectToLogin: TComboBox;
  ComboConnectToRoom: TComboBox;

  btnAddLine: TButton;
  btnRemoveLine: TButton;
  btnClear: TButton;

  Label9: TLabel;
  Label10: TLabel;
  Label11: TLabel;
  Label12: TLabel;
  Label13: TLabel;
  Label14: TLabel;
  Label15: TLabel;
  Label16: TLabel;

  EditAuthLogin: TEdit;
  EditServerAddr: TEdit;

  CheckBoxRegLine: TCheckBox;

  RadioLineTypeUDP: TRadioButton;
  RadioLineTypeTCP: TRadioButton;
  RadioLineTypeTLS: TRadioButton;

  procedure AddLine_Click(Sender: TObject);
  procedure RemoveLine_Click(Sender: TObject);

  procedure ComboLine_SelIndexChanged(Sender: TObject);

  procedure DisableCodec_Click(Sender: TObject);
  procedure EnableCodec_Click(Sender: TObject);

  procedure ClearDlg_Click(Sender: TObject);

  public
  constructor Create(AOwner: TComponent); reintroduce; overload;

  private
  procedure AddUsers();
  procedure AddLines();
  procedure AddRooms();

  procedure ShowLineDetails();

  function AddLineChecks(var sInboundCallTo: string; var nInboundCallType: Integer): boolean;
  procedure ClearDlgUI();

  private
  procedure UpdateLineTypeUI(nLineType: Integer);
  procedure UpdateAudioCodecUI(sAudioCodecList: string);
  procedure UpdateDlgUI(sLineName: string; nLineType: Integer; sAuthLogin: string; sAuthPwd: string; sServerAddr: string; nServerPort: Integer; sAudioCodecList: string; bRegister: boolean; sToPeerName: string; bRejected: boolean; sRoomName: string);

  function GetAudioCodecUI(): string;
  function GetLineTypeUI(): Integer;

  procedure GetIncomingCallInfo(var sToPeerName: string; var bRejected: boolean; var sRoomName: string);
  procedure UpdateIncomingCallUI(sToPeerName: string; bRejected: boolean; sRoomName: string);

  public
  procedure OnSetActive();

end;

var
  AddLineForm: TAddLineForm;


implementation

{$R *.dfm}

  constructor TAddLineForm.Create(AOwner: TComponent);
  begin
    inherited Create(AOwner);
    ClearDlgUI();
  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  procedure TAddLineForm.AddLine_Click(Sender: TObject);
  var
    sLineName, sInCallTo, sAudioCodecList, sToPeerName: string;
    sRoomName: string;
    nInCallType, nLineType: Integer;
    bRejected: boolean;
    bIsUpdated: Boolean;
  begin

    sLineName := ComboLine.Text;

    sInCallTo := '';
    nInCallType := -1;

    if(AddLineChecks(sInCallTo, nInCallType) = False) then
        Exit();

    bIsUpdated := False;

    if(ComboLine.Items.IndexOf(sLineName) <> -1) then
    begin
        if MessageDlg('Line already exists, do you want to continue?', mtConfirmation, [mbYes, mbNo], 0, mbNo) = mrNo then
        begin
          Exit();
        end;

        bIsUpdated := True;
    end;

    ////////////////////////////////////////////////////////////////////////////

    sToPeerName := ''; sRoomName := '';
    bRejected := false;

    GetIncomingCallInfo(sToPeerName, bRejected, sRoomName);

    ////////////////////////////////////////////////////////////////////////////

    sAudioCodecList := GetAudioCodecUI();
    nLineType := GetLineTypeUI();

    ////////////////////////////////////////////////////////////////////////////

    if(TVaxLine.AddLine(sLineName, nLineType, EditAuthLogin.Text, EditAuthPwd.Text, EditServerAddr.Text, StrToInt(EditServerPort.Text), sAudioCodecList, CheckBoxRegLine.Checked, sToPeerName, bRejected, sRoomName) = False) then
    begin
        ShowMessage('Line could not be added or Please start the server first.');
        Exit();
    end;

    if(ComboLine.Items.IndexOf(sLineName) = -1) Then
      ComboLine.Items.Add(sLineName);

    if bIsUpdated then
      ShowMessage('Line updated successfully.')
    else
      ShowMessage('Line added successfully.');

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  procedure TAddLineForm.RemoveLine_Click(Sender: TObject);
  var
    sLineName: string;
    nIndex: Integer;
  begin

    sLineName := ComboLine.Text;

    if(Length(sLineName) = 0) then
    begin
      ShowMessage('Please enter a valid line name.');
      Exit();
    end;

    TVaxLine.RemoveLine(sLineName);

    nIndex := ComboLine.Items.IndexOf(sLineName);

    if(nIndex <> -1) Then
      ComboLine.Items.Delete(nIndex);

    ShowMessage('Line removed successfully.');
    ShowLineDetails();

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  procedure TAddLineForm.ShowLineDetails();
  var
    sLineName, sAuthLogin, sAuthPwd, sServerAddr, sAudioCodecList: string;
    sToPeerName, sRoomName: string;

    nServerPort, nLineType: Integer;
    bRegister, bRejected: boolean;
  begin

    if(ComboLine.Items.Count = 0) then
    begin
      ClearDlgUI();
      Exit();
    end;

    if(ComboLine.ItemIndex = -1) then
      ComboLine.ItemIndex := 0;

    sLineName := ComboLine.Text;

    TStoreLine.GetLine(sLineName, nLineType, sAuthLogin, sAuthPwd, sServerAddr, nServerPort, sAudioCodecList, bRegister, sToPeerName, bRejected, sRoomName);
    UpdateDlgUI(sLineName, nLineType, sAuthLogin, sAuthPwd, sServerAddr, nServerPort, sAudioCodecList, bRegister, sToPeerName, bRejected, sRoomName);

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  procedure TAddLineForm.UpdateDlgUI(sLineName: string; nLineType: Integer; sAuthLogin: string; sAuthPwd: string; sServerAddr: string; nServerPort: Integer; sAudioCodecList: string; bRegister: boolean; sToPeerName: string; bRejected: boolean; sRoomName: string);
  begin

    EditAuthLogin.Text := sAuthLogin;
    EditAuthPwd.Text := sAuthPwd;

    EditServerAddr.Text := sServerAddr;
    EditServerPort.Text := IntToStr(nServerPort);

    CheckBoxRegLine.Checked := bRegister;

    UpdateLineTypeUI(nLineType);
    UpdateAudioCodecUI(sAudioCodecList);

    UpdateIncomingCallUI(sToPeerName, bRejected, sRoomName);

  end;

  //////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////

  procedure TAddLineForm.UpdateAudioCodecUI(sAudioCodecList: string);
  var
    nIndex: Integer;
    sCodecs, sCodecName: string;
  begin

    ListBoxEnableCodecs.Items.Clear();
    ListBoxDisableCodecs.Items.Clear();

    sCodecs := '';

    for nIndex := 0 to TVaxServerCOM.VAX_CODEC_TOTAL_COUNT - 1 do
        ListBoxDisableCodecs.Items.Add(TCodec.GetCodecName(nIndex));

    for nIndex := 1 to Length(sAudioCodecList) do
    begin
        sCodecName := TCodec.GetCodecName(sAudioCodecList[nIndex]);
        ListBoxEnableCodecs.Items.Add(sCodecName);
        ListBoxDisableCodecs.Items.Delete(ListBoxDisableCodecs.Items.IndexOf(sCodecName));
    end;

  end;

  function TAddLineForm.GetAudioCodecUI(): string;
  var
    sCodecName, sCodecNo: string;
    sCodecList: string;
    nCount: Integer;
  begin

    sCodecList := ''; sCodecName := '';

    for nCount := 0 to ListBoxEnableCodecs.Items.Count - 1 do
    begin
      sCodecName := ListBoxEnableCodecs.Items[nCount];
      sCodecNo := TCodec.GetCodecNo(sCodecName);
      sCodecList := sCodecList + sCodecNo;
    end;

    Result := sCodecList;

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  procedure TAddLineForm.GetIncomingCallInfo(var sToPeerName: string; var bRejected: boolean; var sRoomName: string);
  begin

    bRejected := RadioRejectCall.Checked;

    if(RadioConnectToLogin.Checked = True) then
    begin
      sToPeerName := ComboConnectToLogin.Text;
    end
    else if(RadioConnectToRoom.Checked = True) then
      sRoomName := ComboConnectToRoom.Text

  end;

  procedure TAddLineForm.UpdateIncomingCallUI(sToPeerName: string; bRejected: boolean; sRoomName: string);
  var
    nIndex: Integer;
  begin

    if(bRejected = True) then
      RadioRejectCall.Checked := True;

    if(Length(sToPeerName) <> 0) then
    begin
      nIndex := ComboConnectToLogin.Items.IndexOf(sToPeerName);
      if(nIndex = -1) then
      begin
        RadioRejectCall.Checked := True;
        Exit();
      end;

      ComboConnectToLogin.ItemIndex := nIndex;
      RadioConnectToLogin.Checked := True;
    end;

    if(Length(sRoomName) <> 0) then
    begin
      nIndex := ComboConnectToRoom.Items.IndexOf(sRoomName);

      if(nIndex = -1) then
      begin
        RadioRejectCall.Checked := True;
        Exit();
      end;

      ComboConnectToRoom.ItemIndex := nIndex;
      RadioConnectToRoom.Checked := True;
    end;

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  procedure TAddLineForm.UpdateLineTypeUI(nLineType: Integer);
  begin

    if(nLineType = TVaxServerCOM.VAX_LINE_TYPE_UDP) then
      RadioLineTypeUDP.Checked := True

    else if(nLineType = TVaxServerCOM.VAX_LINE_TYPE_TCP) then
      RadioLineTypeTCP.Checked := True

    else if(nLineType = TVaxServerCOM.VAX_LINE_TYPE_TLS) then
      RadioLineTypeTLS.Checked := True

    else
      RadioLineTypeUDP.Checked := True;

  end;

  function TAddLineForm.GetLineTypeUI(): Integer;
  begin

    if(RadioLineTypeUDP.Checked = True) then
      Exit(TVaxServerCOM.VAX_LINE_TYPE_UDP);

    if(RadioLineTypeTCP.Checked = True) then
      Exit(TVaxServerCOM.VAX_LINE_TYPE_TCP);

    if(RadioLineTypeTLS.Checked = True) then
      Exit(TVaxServerCOM.VAX_LINE_TYPE_TLS);

    Exit(TVaxServerCOM.VAX_LINE_TYPE_UDP);

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  procedure TAddLineForm.ClearDlg_Click(Sender: TObject);
  begin
    ClearDlgUI();
  end;

  procedure TAddLineForm.ComboLine_SelIndexChanged(Sender: TObject);
  begin
    ShowLineDetails();
  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  procedure TAddLineForm.DisableCodec_Click(Sender: TObject);
  begin

    if(ListBoxEnableCodecs.Items.Count <= 0) then
        Exit();

    if(ListBoxEnableCodecs.ItemIndex = -1) then
    begin
      ShowMessage('Please choose a codec first');
      Exit();
    end;

    ListBoxDisableCodecs.Items.Add(ListBoxEnableCodecs.Items[ListBoxEnableCodecs.ItemIndex]);
    ListBoxEnableCodecs.Items.Delete(ListBoxEnableCodecs.ItemIndex);

  end;

  procedure TAddLineForm.EnableCodec_Click(Sender: TObject);
  begin

    if(ListBoxDisableCodecs.Items.Count <= 0) then
      Exit();

    if(ListBoxDisableCodecs.ItemIndex = -1) then
    begin
      ShowMessage('Please choose a codec first');
      Exit();
    end;

    ListBoxEnableCodecs.Items.Add(ListBoxDisableCodecs.Items[ListBoxDisableCodecs.ItemIndex]);
    ListBoxDisableCodecs.Items.Delete(ListBoxDisableCodecs.ItemIndex);

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  procedure TAddLineForm.OnSetActive();
  begin
    AddUsers();
    AddRooms();
    AddLines();
  end;

  procedure TAddLineForm.AddUsers();
  var
    nIndex: Integer;
    objListUsers: TStringList;
  begin

    objListUsers := TStringList.Create();
    TStoreUser.GetUserAll(objListUsers);

    if(objListUsers.Count <= 0) then
        Exit();

    ComboConnectToLogin.Clear();

    for nIndex := 0 to objListUsers.Count - 1 do
        ComboConnectToLogin.Items.Add(objListUsers[nIndex]);

    if(ComboConnectToLogin.ItemIndex = -1) then
      ComboConnectToLogin.ItemIndex := 0;

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  procedure TAddLineForm.AddLines();
  var
    objList: TStringList;
    nIndex: Integer;
  begin

    objList := TStringList.Create();
    TStoreLine.GetLineAll(objList);

    if(objList.Count <= 0) then
    begin
      ClearDlgUI();
      Exit();
    end;

    ComboLine.Clear();

    for nIndex := 0 to objList.Count - 1 do
        ComboLine.Items.Add(objList[nIndex]);

    if(ComboLine.ItemIndex = -1) then
      ComboLine.ItemIndex := 0;

    ShowLineDetails();

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  procedure TAddLineForm.AddRooms();
  var
    objList: TStringList;
    nCount: Integer;
  begin

    objList := TStringList.Create();
    TStoreRoom.GetRoomNameAll(objList);

    if(objList.Count <= 0) then
        Exit();

    ComboConnectToRoom.Clear();

    for nCount := 0 to objList.Count - 1 do
        ComboConnectToRoom.Items.Add(objList[nCount]);

    if(ComboConnectToRoom.ItemIndex = -1) then
      ComboConnectToRoom.ItemIndex := 0;

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  procedure TAddLineForm.ClearDlgUI();
  begin

    ComboLine.Text := '';

    EditAuthLogin.Text := '';
    EditAuthPwd.Text := '';

    CheckBoxRegLine.Checked := False;

    EditServerAddr.Text:= '';
    EditServerPort.Text := IntToStr(TVaxServerCOM.SIP_DEFAULT_PORT);

    if(ComboConnectToLogin.Items.Count > 0) then
      ComboConnectToLogin.ItemIndex := 0;

    if(ComboConnectToRoom.Items.Count > 0) then
      ComboConnectToRoom.ItemIndex := 0;

    RadioRejectCall.Checked := True;
    RadioLineTypeUDP.Checked := True;

    ListBoxEnableCodecs.Items.Clear();
    ListBoxDisableCodecs.Items.Clear();

    ListBoxEnableCodecs.Items.Add(TCodec.AUDIO_CODEC_NAME_G711U);
    ListBoxEnableCodecs.Items.Add(TCodec.AUDIO_CODEC_NAME_G711A);
    ListBoxEnableCodecs.Items.Add(TCodec.AUDIO_CODEC_NAME_ILBC);
    ListBoxEnableCodecs.Items.Add(TCodec.AUDIO_CODEC_NAME_GSM610);
    ListBoxEnableCodecs.Items.Add(TCodec.AUDIO_CODEC_NAME_G729);

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  function TAddLineForm.AddLineChecks(var sInboundCallTo: string; var nInboundCallType: Integer): boolean;
  begin

    if(Length(ComboLine.Text) = 0) then
    begin
      ShowMessage('Please enter line name.');
      Exit(False);
    end;

    if(ListBoxEnableCodecs.Items.Count <= 0) then
    begin
      ShowMessage('Please select a codec.');
      Exit(False);
    end;

    nInboundCallType := -1;

    if(RadioRejectCall.Checked = True) then
        sInboundCallTo := '';

    if(RadioConnectToLogin.Checked = True) then
    begin

      if(ComboConnectToLogin.ItemIndex = -1) then
      begin
        ShowMessage('Please select a user to forward the incoming call.');
        Exit(False);
      end;

      nInboundCallType := TVaxServerCOM.VAX_PEER_TYPE_USER;
      sInboundCallTo := ComboConnectToLogin.Text;

    end;

    if(RadioConnectToRoom.Checked = True) then
    begin

      if(ComboConnectToRoom.ItemIndex = -1) then
      begin
        ShowMessage('Please select a conference room.');
        Exit(False);
      end;

      sInboundCallTo := ComboConnectToRoom.Text;

    end;

    Result := True;

  end;


end.
