unit AddRoomDlg;

Interface

uses

  Winapi.Windows, Winapi.Messages,
  System.SysUtils, System.StrUtils,
  System.Variants, System.Classes,

  Vcl.Graphics, Vcl.Controls, Vcl.Forms,
  Vcl.Dialogs, Vcl.StdCtrls, Vcl.ExtCtrls,

  StoreRoom,

  VaxRoom,
  VaxServerSIP, VaxDefine;

type TAddRoomForm = class(TForm)

  GroupBox1: TGroupBox;
  Label1: TLabel;
  Label2: TLabel;

  ComboRoomName: TComboBox;
  EditRoomNo: TEdit;
  btnAddRoom: TButton;
  btnRemoveRoom: TButton;

  procedure AddRoom_Click(Sender: TObject);
  procedure RemoveRoom_Click(Sender: TObject);

  function AddRoomChecks(): Boolean;
  procedure OnComboRoomNameSelectChange(Sender: TObject);

  public
  constructor Create(AOwner: TComponent); reintroduce; overload;
  procedure OnSetActive();

  private
  procedure AddRooms();
  procedure ShowRoomDetails();
  procedure ClearDlgUI();

end;

var
  AddRoomForm: TAddRoomForm;

implementation

{$R *.dfm}

  constructor TAddRoomForm.Create(AOwner : TComponent);
  begin
    inherited Create(AOwner);
    ClearDlgUI();
  end;

  //////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////

  procedure TAddRoomForm.AddRoom_Click(Sender: TObject);
  var
    sRoomName: string;
    bIsUpdated: Boolean;
  begin

    if(AddRoomChecks() = False) Then
      Exit();

    bIsUpdated := False;
    sRoomName := Trim(ComboRoomName.Text);

    if(ComboRoomName.Items.IndexOf(sRoomName) <> -1) then
    begin
      if MessageDlg('Room already exists, do you want to continue?', mtConfirmation, [mbYes, mbNo], 0, mbNo) = mrNo then
      begin
        Exit();
      end;

      bIsUpdated := True;
    end;

    if(TVaxRoom.AddRoom(sRoomName, Trim(EditRoomNo.Text)) = False) Then
    begin
      ShowMessage('Room could not be added/updated. Please start the server first or can''t assign same Dial-in No to multiple rooms.');
      Exit();
    end;

    if(ComboRoomName.Items.IndexOf(sRoomName) = -1) Then
      ComboRoomName.Items.Add(sRoomName);

    if bIsUpdated then
      ShowMessage('Room updated successfully.')
    else
      ShowMessage('Room added successfully.');

  end;

  //////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////

  function TAddRoomForm.AddRoomChecks(): Boolean;
  var
    sRoomName, sRoomNo: string;
  begin

    if Length(Trim(ComboRoomName.Text)) <= 0 then
    begin
      ShowMessage('Please enter a valid room name.');
      Exit(False);
    end;

    if Length(Trim(EditRoomNo.Text)) <= 0 then
    begin
      ShowMessage('Please enter a valid room no.');
      Exit(False);
    end;

    sRoomName := Trim(ComboRoomName.Text);
    sRoomNo := EditRoomNo.Text;

    if(Not TVaxDefine.IsDigitAll(sRoomNo)) Then
    begin
      ShowMessage('Room No should contain only numerals 0 through 9. For example: 12, 324323, 800122, 2109756 etc.');
      Exit(False);
    end;

    Result := True;
  end;

  //////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////

  procedure TAddRoomForm.RemoveRoom_Click(Sender: TObject);
  var
    sRoomName: string;
    nIndex: Integer;
  begin

    sRoomName := Trim(ComboRoomName.Text);
    TVaxRoom.RemoveRoom(sRoomName);

    nIndex := ComboRoomName.Items.IndexOf(sRoomName);

    if(nIndex <> -1) Then
      ComboRoomName.Items.Delete(nIndex);

    ShowMessage('Room removed successfully!');
    ShowRoomDetails();

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  procedure TAddRoomForm.OnComboRoomNameSelectChange(Sender: TObject);
  begin
     ShowRoomDetails();
  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  procedure TAddRoomForm.OnSetActive();
  begin
    AddRooms();
  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  procedure TAddRoomForm.AddRooms();
  var
    objListRooms: TStringList;
    nCount: Integer;
  begin

    objListRooms := TStringList.Create();
    TStoreRoom.GetRoomNameAll(objListRooms);

    if(objListRooms.Count <= 0) then
        exit;

    ComboRoomName.Clear();

    for nCount := 0 to objListRooms.Count - 1 do
        ComboRoomName.Items.Add(objListRooms[nCount]);

    ShowRoomDetails();

  end;

  //////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////

  procedure TAddRoomForm.ShowRoomDetails();
  var
    sRoomName, sRoomNo: string;
  begin

    if(ComboRoomName.Items.Count = 0) then
    begin
      ClearDlgUI();
      Exit();
    end;

    if(ComboRoomName.ItemIndex = -1) then
      ComboRoomName.ItemIndex := 0;

    sRoomName := Trim(ComboRoomName.Text);

    if(TStoreRoom.GetRoom(sRoomName, sRoomNo) = False) then
      Exit;

    EditRoomNo.Text := sRoomNo;

  end;

  procedure TAddRoomForm.ClearDlgUI();
  begin
    ComboRoomName.Text := '';
    EditRoomNo.Text := '';
  end;

  //////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////

end.
