unit SIPRecDlg;

interface

uses
  Winapi.Windows, Winapi.Messages, System.SysUtils, System.Variants, System.Classes, Vcl.Graphics,
  Vcl.Controls, Vcl.Forms, Vcl.Dialogs, Vcl.StdCtrls, Vcl.ComCtrls;

type

  TSIPRecForm = class(TForm)

  Label1: TLabel;
  Label2: TLabel;
  Label3: TLabel;
  Label4: TLabel;

  EditAuthLogin: TEdit;
  EditAuthPwd: TEdit;
  EditServerAddr: TEdit;

  CheckBoxSIPServerREC: TCheckBox;
  BtnOnline: TButton;

  GroupBox1: TGroupBox;
  GroupBox2: TGroupBox;

  ListStatus: TListBox;
  btnCLearStatus: TButton;
  EditServerPort: TEdit;

  procedure BtnOnlineClick(Sender: TObject);
  procedure btnCLearStatusClick(Sender: TObject);

  public
  constructor Create(AOwner: TComponent); reintroduce; overload;
  procedure OnSetActive();

  procedure OnLineRegisterTryingREC(sLineName: string);
  procedure OnLineRegisterFailedREC(sLineName: string; nStatusCode: Integer;  sReasonPhrase: string);
  procedure OnLineRegisterSuccessREC(sLineName: string);
  procedure OnLineUnRegisterTryingREC(sLineName: string);
  procedure OnLineUnRegisterFailedREC(sLineName: string; nStatusCode: Integer;  sReasonPhrase: string);
  procedure OnLineUnRegisterSuccessREC(sLineName: string);

  procedure OnServerConnectingREC(nSessionId: Integer; nChannelId: Integer; nStatusCode: Integer; sReasonPhrase: string);
  procedure OnServerConnectedREC(nSessionId: Integer; nChannelId: Integer);
  procedure OnServerFailedREC(nSessionId: Integer; nChannelId: Integer; nStatusCode: Integer; sReasonPhrase: string);
  procedure OnServerTimeoutREC(nSessionId: Integer; nChannelId: Integer);
  procedure OnServerHungupREC(nSessionId: Integer; nChannelId: Integer);

  procedure OnStatusLog(sStatus: string);

end;

var
  SIPRecForm: TSIPRecForm;

implementation

uses
  VaxServerSIP;

{$R *.dfm}

  constructor TSIPRECForm.Create(AOwner: TComponent);
  begin
    inherited Create(AOwner);
  end;

  procedure TSIPRecForm.BtnOnlineClick(Sender: TObject);
  var
    sStatus: string;
  begin

    if(Length(EditAuthLogin.Text) = 0) or (Length(EditServerAddr.Text) = 0) then
      Exit();

    if BtnOnline.Caption = 'Offline' Then
    begin
      BtnOnline.Caption := 'Online';
      TVaxServerSIP.mVaxSIP.DeactivateREC();
      Exit();
    end;

    BtnOnline.Caption := 'Offline';

    TVaxServerSIP.mVaxSIP.ActivateREC(EditAuthLogin.Text, EditAuthPwd.Text, EditServerAddr.Text, StrToInt(EditServerPort.Text), CheckBoxSIPServerREC.Checked);

    if CheckBoxSIPServerREC.Checked = False then
    begin
      sStatus := 'Account is online';
      OnStatusLog(sStatus);
    end;

  end;

  procedure TSIPRECForm.OnSetActive();
  begin
  end;

  ///////////////////////////////////////////////////////////////////////////////////////
  ///////////////////////////////////////////////////////////////////////////////////////

  procedure TSIPRecForm.OnLineRegisterTryingREC(sLineName: string);
  var
    sStatus: string;
  begin
    sStatus := sLineName + ': Trying to register';
    OnStatusLog(sStatus);
  end;

  procedure TSIPRecForm.OnLineRegisterFailedREC(sLineName: string; nStatusCode: Integer; sReasonPhrase: string);
  var
    sStatus: string;
  begin
    sStatus := sLineName + ': Failed to register (' + sReasonPhrase + ')';
    OnStatusLog(sStatus);
  end;

  procedure TSIPRecForm.OnLineRegisterSuccessREC(sLineName: string);
  var
    sStatus: string;
  begin
    sStatus := sLineName + ': Registered successfully';
    OnStatusLog(sStatus);
  end;

  ///////////////////////////////////////////////////////////////////////////////////////
  ///////////////////////////////////////////////////////////////////////////////////////

  procedure TSIPRecForm.OnLineUnRegisterTryingREC(sLineName: string);
  var
    sStatus: string;
  begin
    sStatus := sLineName + ': Trying to unregister';
    OnStatusLog(sStatus);
  end;

  procedure TSIPRecForm.OnLineUnRegisterFailedREC(sLineName: string; nStatusCode: Integer; sReasonPhrase: string);
  var
    sStatus: string;
  begin
    sStatus := sLineName + ': Failed to unregister (' + sReasonPhrase + ')';
    OnStatusLog(sStatus);
  end;

  procedure TSIPRecForm.OnLineUnRegisterSuccessREC(sLineName: string);
  var
    sStatus: string;
  begin
    sStatus := sLineName + ': Unregistered successfully';
    OnStatusLog(sStatus);
  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  procedure TSIPRecForm.OnServerConnectingREC(nSessionId: Integer; nChannelId: Integer; nStatusCode: Integer; sReasonPhrase: string);
  var
    sStatus: string;
  begin
    sStatus := 'Session: ' + IntToStr(nSessionId) + ' trying to connect';
    OnStatusLog(sStatus);
  end;

  procedure TSIPRecForm.OnServerConnectedREC(nSessionId: Integer; nChannelId: Integer);
  var
    sStatus: string;
  begin
    sStatus := 'Session: ' + IntToStr(nSessionId) + ' connected successfully';
    OnStatusLog(sStatus);
  end;

  procedure TSIPRecForm.OnServerFailedREC(nSessionId: Integer; nChannelId: Integer; nStatusCode: Integer; sReasonPhrase: string);
  var
    sStatus: string;
  begin
    sStatus := 'Session: ' + IntToStr(nSessionId) + ' failed to connect' + ' (' + sReasonPhrase + ')';
    OnStatusLog(sStatus);
  end;

  procedure TSIPRecForm.OnServerTimeoutREC(nSessionId: Integer; nChannelId: Integer);
  var
    sStatus: string;
  begin
    sStatus := 'Session: ' + IntToStr(nSessionId) + ' failed to connect (timeout)';
    OnStatusLog(sStatus);
  end;

  procedure TSIPRecForm.OnServerHungupREC(nSessionId: Integer; nChannelId: Integer);
  var
    sStatus: string;
  begin
    sStatus := 'Session: ' + IntToStr(nSessionId) + ' Hungup';
    OnStatusLog(sStatus);
  end;

  //////////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////////

  procedure TSIPRecForm.btnClearStatusClick(Sender: TObject);
  var
    tabStatusLogSheet : TTabSheet;
  begin
    ListStatus.Clear();

    tabStatusLogSheet := TTabSheet(Self.Parent);
    tabStatusLogSheet.Caption := 'SIP REC';
  end;

  procedure TSIPRecForm.OnStatuslog(sStatus: string);
  var
    nTotalCount: Integer;
    tabStatusLogSheet : TTabSheet;
  begin
    ListStatus.Items.Add(sStatus);

    nTotalCount := ListStatus.Items.Count;

    tabStatusLogSheet := TTabSheet(Self.Parent);
    tabStatusLogSheet.Caption := 'SIP REC (' + IntToStr(nTotalCount) + ')';
  end;

end.
