unit VaxCallSession;

interface

uses
  System.Classes,

  VaxCallSessionRoute, VaxDefine, VaxCall,
  VaxDetectAMD, VaxDTMF, VaxAccessAudioPCM,
  VaxRoom, VaxTransfer;

type TVaxCallSession = class(TObject)

  private
  m_objVaxCall: TVaxCall;
  m_objVaxTransfer: TVaxTransfer;

	m_objVaxDTMF: TVaxDTMF;
  m_objVaxAMD: TVaxDetectAMD;
  m_objVaxRoom: TVaxRoom;

  mAccessPCM: TVaxAccessAudioPCM;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  public
  class procedure AddUserRoute(sUserName: String; sUserPrefix: String; sDialPrefix: String; sToPeerName: String);
  class procedure RemoveUserRoute(sUserName: String);

  class procedure AddLineRoute(sLineName: String; sToPeerName: String; bRejected: Boolean; sRoomName: String);
  class procedure RemoveLineRoute(sLineName: String);

  private
  procedure GetFromPeerRouteInfo(nFromPeerType: Integer; sFromPeerName: string; sDialNo: String; var sDialToNo: String; var sToPeerName: String; var bRejected: Boolean; var sRoomName: String);

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  public

  procedure OnCallSessionCreated(nSessionId: Integer; nReasonCode: Integer);
  procedure OnCallSessionClosed(nSessionId: Integer; nChannelId: Integer; nReasonCode: Integer);

  procedure OnIncomingCall(nSessionId: Integer; sCallerName: String; sCallerId: String; sDialNo: String; nFromPeerType: Integer; sFromPeerName: String; sUserAgentName: String; sFromIP: String; nFromPort: Integer);

  private
  procedure OnProcessCall(nSessionId: Integer; sCallerName: String; sCallerId: String; sDialNo: String; nFromPeerType: Integer; sFromPeerName: String; sUserAgentName: String; sFromIP: String; nFromPort: Integer; sToPeerName: String; sRoomName: String);

  public
  procedure OnCallSessionTransferBlind(nTransfererSessionId: Integer; nTransfererChannelId: Integer; sTransferer: String; sTransferee: String; sTransferTo: String);
  procedure OnCallSessionTransferConsult(nTransfererSessionId: Integer; nTransfererChannelId: Integer; nTransferToSessionId: Integer; nTransferToChannelId: Integer; sTransferer: String; sTransferee: String; sTransferTo: String);

  procedure OnDetectedDigitDTMF(nSessionId: Integer; nChannelId: Integer; sDigitDTMF: String);
  procedure OnCallSessionDetectedAMD(nSessionId: Integer; nChannelId: Integer; bIsHuman: Boolean);

  procedure OnCallSessionAccessAudioPCM(nSessionId: Integer; nChannelId: Integer; nAccessType: Integer; pDataPCM: PByte; nSizePCM: Integer);

  public
  constructor Create();
  destructor Destroy(); override;

  class procedure ResetAll();

end;

implementation

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  Uses VaxServerSIP, VaxServerCOM;
  var m_objRouteCallSIP: TVaxCallSessionRoute = nil;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  constructor TVaxCallSession.Create();
  begin

    inherited;

    if(m_objRouteCallSIP = nil) then
      m_objRouteCallSIP := TVaxCallSessionRoute.Create();

    m_objVaxCall := TVaxCall.Create();
    m_objVaxTransfer := TVaxTransfer.Create();

    m_objVaxRoom := TVaxRoom.Create();
    m_objVaxDTMF := TVaxDTMF.Create();
    m_objVaxAMD := TVaxDetectAMD.Create();

  end;

  destructor TVaxCallSession.Destroy();
  begin

    inherited;

    m_objVaxCall.Destroy();
    m_objVaxTransfer.Destroy();

    m_objVaxRoom.Destroy();

    m_objVaxDTMF.Destroy();
    m_objVaxAMD.Destroy();

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class procedure TVaxCallSession.ResetAll();
  begin

    if(m_objRouteCallSIP <> nil) then
    begin
      m_objRouteCallSIP.Destroy();
      m_objRouteCallSIP := nil;
    end;

    m_objRouteCallSIP := TVaxCallSessionRoute.Create();

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  procedure TVaxCallSession.OnCallSessionCreated(nSessionId: Integer; nReasonCode: Integer);
  begin

    mAccessPCM := TVaxAccessAudioPCM.Create(nSessionId, TVaxServerCOM.VAX_CALL_CHANNEL_ZERO);

  end;

  procedure TVaxCallSession.OnCallSessionClosed(nSessionId: Integer; nChannelId: Integer; nReasonCode: Integer);
  begin

    mAccessPCM.Destroy();

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class procedure TVaxCallSession.AddUserRoute(sUserName: String; sUserPrefix: String; sDialPrefix: String; sToPeerName: String);
  begin
    m_objRouteCallSIP.AddUserRoute(sUserName, sUserPrefix, sDialPrefix, sToPeerName);
  end;

  class procedure TVaxCallSession.RemoveUserRoute(sUserName: String);
  begin
    m_objRouteCallSIP.RemoveUserRoute(sUserName);
  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class procedure TVaxCallSession.AddLineRoute(sLineName: String; sToPeerName: String; bRejected: Boolean; sRoomName: String);
  begin
    m_objRouteCallSIP.AddLineRoute(sLineName, sToPeerName, bRejected, sRoomName);
  end;

  class procedure TVaxCallSession.RemoveLineRoute(sLineName: String);
  begin
    m_objRouteCallSIP.RemoveLineRoute(sLineName);
  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  procedure TVaxCallSession.GetFromPeerRouteInfo(nFromPeerType: Integer; sFromPeerName: string; sDialNo: String; var sDialToNo: String; var sToPeerName: String; var bRejected: Boolean; var sRoomName: String);
  begin

    if(nFromPeerType = TVaxServerCOM.VAX_PEER_TYPE_USER) Then
    begin
      m_objRouteCallSIP.GetUserRouteInfo(sFromPeerName, sDialNo, sDialToNo, sToPeerName);
      Exit();
    end;

    m_objRouteCallSIP.GetLineRouteInfo(sFromPeerName, sDialNo, sDialToNo, sToPeerName, bRejected, sRoomName);

   end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  procedure TVaxCallSession.OnIncomingCall(nSessionId: Integer; sCallerName: String; sCallerId: String; sDialNo: String; nFromPeerType: Integer; sFromPeerName: String; sUserAgentName: String; sFromIP: String; nFromPort: Integer);
  var
    sToPeerName: String; sDialToNo: String;
    sRoomName: String;
    bRejected: Boolean;
  begin

    sToPeerName := ''; sDialToNo := '';
    sRoomName := '';
    bRejected := false;

    GetFromPeerRouteInfo(nFromPeerType, sFromPeerName, sDialNo, sDialToNo, sToPeerName, bRejected, sRoomName);

    if(bRejected = True) then
    begin
      TVaxServerSIP.mVaxSIP.RejectCallSession(nSessionId, 404, 'Not Found');
      Exit();
    end;

    OnProcessCall(nSessionId, sCallerName, sCallerId, sDialToNo, nFromPeerType, sFromPeerName, sUserAgentName, sFromIP, nFromPort, sToPeerName, sRoomName);

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  procedure TVaxCallSession.OnProcessCall(nSessionId: Integer; sCallerName: String; sCallerId: String; sDialNo: String; nFromPeerType: Integer; sFromPeerName: String; sUserAgentName: String; sFromIP: String; nFromPort: Integer; sToPeerName: String; sRoomName: String);
  var
    bProcessed: Boolean;
  begin

    m_objVaxRoom.OnIncomingCall(nSessionId, sRoomName, bProcessed);
    if(bProcessed) Then Exit();

    m_objVaxCall.OnIncomingCall(nSessionId, sCallerName, sCallerId, sDialNo, nFromPeerType, sFromPeerName, sToPeerName, bProcessed);

  end;

  ///////////////////////////////////////////////////////////////////////////////
  ///////////////////////////////////////////////////////////////////////////////

  procedure TVaxCallSession.OnCallSessionTransferBlind(nTransfererSessionId: Integer; nTransfererChannelId: Integer; sTransferer: String; sTransferee: String; sTransferTo: String);
  begin
    m_objVaxTransfer.OnCallSessionTransferBlind(nTransfererSessionId, nTransfererChannelId, sTransferer, sTransferee, sTransferTo);
  end;

  procedure TVaxCallSession.OnCallSessionTransferConsult(nTransfererSessionId: Integer; nTransfererChannelId: Integer; nTransferToSessionId: Integer; nTransferToChannelId: Integer; sTransferer: String; sTransferee: String; sTransferTo: String);
  begin
    m_objVaxTransfer.OnCallSessionTransferConsult(nTransfererSessionId, nTransfererChannelId, nTransferToSessionId, nTransferToChannelId, sTransferer, sTransferee, sTransferTo);
  end;

  ///////////////////////////////////////////////////////////////////////////////
  ///////////////////////////////////////////////////////////////////////////////

  procedure TVaxCallSession.OnDetectedDigitDTMF(nSessionId: Integer; nChannelId: Integer; sDigitDTMF: String);
  begin
    m_objVaxDTMF.OnDetectedDigitDTMF(nSessionId, nChannelId, sDigitDTMF);
  end;

  ///////////////////////////////////////////////////////////////////////////////
  ///////////////////////////////////////////////////////////////////////////////

  procedure TVaxCallSession.OnCallSessionDetectedAMD(nSessionId: Integer; nChannelId: Integer; bIsHuman: Boolean);
  begin
    m_objVaxAMD.OnCallSessionDetectedAMD(nSessionId, nChannelId, bIsHuman);
  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  procedure TVaxCallSession.OnCallSessionAccessAudioPCM(nSessionId: Integer; nChannelId: Integer; nAccessType: Integer; pDataPCM: PByte; nSizePCM: Integer);
  begin
    mAccessPCM.OnCallSessionAccessAudioPCM(nSessionId, nChannelId, nAccessType, pDataPCM, nSizePCM);
  end;

end.

