unit VaxRoom;

Interface
uses

  System.Classes,

  StoreRoom,
  VaxDefine;

type TVaxRoom = class

  public
  constructor Create();

  public
  procedure OnIncomingCall(nSessionId: Integer; sRoomName: String; var bProcessed: Boolean);

  public
  class function AddRoom(sRoomName: String; sRoomNo: String): Boolean; static;
  class procedure RemoveRoom(sRoomName: String); static;
  class procedure LoadRoom(); static;

end;

implementation

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  Uses VaxServerSIP, VaxServerCOM;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  constructor TVaxRoom.Create();
  begin

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  procedure TVaxRoom.OnIncomingCall(nSessionId: Integer; sRoomName: String; var bProcessed: Boolean);
  begin

    bProcessed := False;

    if(Length(sRoomName) = 0) Then
      Exit();

    if(TVaxServerSIP.mVaxSIP.AddCallSessionToConferenceRoom(sRoomName, nSessionId) = False) Then
    begin
      TVaxServerSIP.mVaxSIP.RejectCallSession(nSessionId, 404, 'Not Found');
      Exit();
    end;

    // Accept incoming call and add to conference room.

    if(TVaxServerSIP.mVaxSIP.AcceptCallSession(nSessionId, '', '', '', '', '') = False) then
    begin
      TVaxServerSIP.mVaxSIP.RejectCallSession(nSessionId, 404, 'Not Found');
      Exit();
    end;

    bProcessed := True;

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class function TVaxRoom.AddRoom(sRoomName: String; sRoomNo: String): Boolean;
  begin

    if((TVaxServerSIP.mVaxSIP.IsInitialized() = False) or (Length(sRoomName) = 0) or (Length(sRoomNo) = 0)) Then
      Exit(False);

    RemoveRoom(sRoomName);

    if(TVaxServerSIP.mVaxSIP.OpenConferenceRoom(sRoomName) = False) then
    begin
      RemoveRoom(sRoomName);
      Exit(False);
    end;

    if(TVaxServerSIP.mVaxSIP.AddConferenceRoomRouteUID(sRoomName, sRoomNo) = False) Then
    begin
      RemoveRoom(sRoomName);
      Exit(False);
    end;

    TStoreRoom.AddRoom(sRoomName, sRoomNo);
    Result := True;

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class procedure TVaxRoom.RemoveRoom(sRoomName: String);
  begin

    if((TVaxServerSIP.mVaxSIP.IsInitialized() = False) or (Length(sRoomName) = 0)) Then
      Exit();

    TVaxServerSIP.mVaxSIP.CloseConferenceRoom(sRoomName);
    TStoreRoom.RemoveRoom(sRoomName);

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class procedure TVaxRoom.LoadRoom();
  var
    sRoomName, sRoomNo: string;
    objListRoomName: TStringList;
  begin

    if(TVaxServerSIP.mVaxSIP.IsInitialized() = False) Then
      Exit();

    objListRoomName :=  TStringList.Create();
    TStoreRoom.GetRoomNameAll(objListRoomName);

    if(objListRoomName.Count = 0) Then
      Exit();

    sRoomNo := '';

    for sRoomName in objListRoomName do
    begin
      TStoreRoom.GetRoom(sRoomName, sRoomNo);
      AddRoom(sRoomName, sRoomNo);
    end;

  end;


end.
