unit VaxStealthListen;

Interface
uses

  System.Classes, SysUtils,
  VaxUser;

type TVaxStealthListen  = class

  public
  constructor Create();

  public
  class procedure ResetAll(); static;
  class function LoadMusic(sFileName: String): Boolean; static;

  public
  class procedure OnIncomingCall(nSessionId: Integer; sCallerName: String; sCallerId: String; sDialNo: String; nFromPeerType: Integer; sFromPeerName: String; sRouteUID: String); static;
  class procedure OnStealthListenerAttached(nAttachType: Integer; nStealthSessionId: Integer; nAttachSessionId: Integer; nAttachChannelId: Integer); static;

  private
  class procedure StartMusic(nSessionId: Integer; nChannelId: Integer); static;
  class procedure StopMusic(nSessionId: Integer); static;

end;

implementation

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  Uses VaxServerSIP, VaxServerCOM;
  var m_nMusicWaitingStealthListenId: Integer = -1;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  constructor TVaxStealthListen.Create();
  begin

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class procedure TVaxStealthListen.ResetAll();
  begin
    m_nMusicWaitingStealthListenId := -1;
  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class procedure TVaxStealthListen.OnIncomingCall(nSessionId: Integer; sCallerName: String; sCallerId: String; sDialNo: String; nFromPeerType: Integer; sFromPeerName: String; sRouteUID: String);
  begin

    if((nFromPeerType <> TVaxServerCOM.VAX_PEER_TYPE_USER) OR (TVaxUser.IsUserTypeAdmin(sFromPeerName) = False)) Then
    Begin
      TVaxServerSIP.mVaxSIP.RejectCallSession(nSessionId, 403, 'Forbidden');
      Exit();
    End;

    TVaxServerSIP.mVaxSIP.AcceptCallSession(nSessionId, sCallerName, sCallerId, sDialNo, '', sRouteUID);
    TVaxServerSIP.mVaxSIP.AdjustCallSessionVoiceType(nSessionId, -1, TVaxServerCOM.VAX_AUDIO_TYPE_ADMIN);

    StartMusic(nSessionId, TVaxServerCOM.VAX_CALL_CHANNEL_ZERO);

  end;

  class procedure TVaxStealthListen.OnStealthListenerAttached(nAttachType: Integer; nStealthSessionId: Integer; nAttachSessionId: Integer; nAttachChannelId: Integer);
  begin

    if(nAttachType = TVaxServerCOM.VAX_STEALTH_LISTENER_FREE) Then
    begin
      StartMusic(nStealthSessionId, TVaxServerCOM.VAX_CALL_CHANNEL_ZERO);
      Exit();
    end;

    if(nAttachType = TVaxServerCOM.VAX_STEALTH_LISTENER_BUSY) Then
    begin
      StopMusic(nStealthSessionId);
      Exit();
    end;

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class function TVaxStealthListen.LoadMusic(sFileName: String): Boolean;
  begin

    if(m_nMusicWaitingStealthListenId <> -1) Then
    begin
      TVaxServerSIP.mVaxSIP.UnLoadWaveID(m_nMusicWaitingStealthListenId);
      m_nMusicWaitingStealthListenId := -1;
    end;

    m_nMusicWaitingStealthListenId := TVaxServerSIP.mVaxSIP.LoadWaveFile(sFileName);

    if(m_nMusicWaitingStealthListenId = -1) Then
      Exit(False);

    Result := True;

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class procedure TVaxStealthListen.StartMusic(nSessionId: Integer; nChannelId: Integer);
  var
    nMusicId: Integer;
  begin

    nMusicId := m_nMusicWaitingStealthListenId;

    if(nMusicId = -1) then
      Exit();

    TVaxServerSIP.mVaxSIP.PlayWaveStartToCallSession(nSessionId, nChannelId, nMusicId, True, 0);

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class procedure TVaxStealthListen.StopMusic(nSessionId: Integer);
  begin

    if(m_nMusicWaitingStealthListenId = -1) Then
      Exit();

    TVaxServerSIP.mVaxSIP.PlayWaveStopToCallSession(nSessionId, -1, -1);

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

end.
