﻿unit StoreRoom;

Interface

uses

  Winapi.Windows,
  Winapi.Messages,
  System.SysUtils,
  System.Classes,
  StoreRegistry, VaxServerCOM;

type TStoreRoom = class

  private
  const ROOM_ROOT_PATH = 'Rooms\\';

  public
  class function AddRoom(sRoomName: String; sRoomNo: String): Boolean; static;
  class function GetRoom(sRoomName: String; var sRoomNo: String): Boolean; static;

  class procedure RemoveRoom(sRoomName: String); static;
  class procedure GetRoomNameAll(var objList: TStringList); static;

  class function IsDataStored(): Boolean; static;

end;


implementation

  //////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////

  class function TStoreRoom.AddRoom(sRoomName: String; sRoomNo: String): Boolean;
  var
    sKeyPath: String;
    objStore: TStoreRegistry;
  begin

    if Length(sRoomName) = 0 then
    begin
      Exit(False);
    end;

    sKeyPath := ROOM_ROOT_PATH + sRoomName;
    objStore := TStoreRegistry.Create();

    objStore.SetTEXT(sKeyPath, 'RoomNo', sRoomNo);
    objStore.Destroy();

    Result := True;

  end;

  class function TStoreRoom.GetRoom(sRoomName: String; var sRoomNo: String): Boolean;
  var
    sKeyPath: String;
    objStore: TStoreRegistry;
  begin

    if Length(sRoomName) = 0 then
    begin
      Exit(False);
    end;

    sKeyPath := ROOM_ROOT_PATH + sRoomName;
    objStore := TStoreRegistry.Create();

    objStore.GetTEXT(sKeyPath, 'RoomNo', sRoomNo, '');
    objStore.Destroy();

    Result := True;

  end;

  class procedure TStoreRoom.RemoveRoom(sRoomName: String);
  var
    sKeyPath: String;
    objStore: TStoreRegistry;
  begin

    if Length(sRoomName) = 0 then
    begin
      Exit();
    end;

    sKeyPath := ROOM_ROOT_PATH + sRoomName;
    objStore := TStoreRegistry.Create();

    objStore.DeleteSubKey(sKeyPath);
    objStore.Destroy();

  end;

  class procedure TStoreRoom.GetRoomNameAll(var objList: TStringList);
  var
    sKeyPath: String;
    objStore: TStoreRegistry;
  begin

    sKeyPath := ROOM_ROOT_PATH;
    objStore := TStoreRegistry.Create();

    objStore.EnumSubKeys(sKeyPath, objList);
    objStore.Destroy();

  end;

  class function TStoreRoom.IsDataStored(): Boolean;
  var
    objStore: TStoreRegistry;
  begin
    objStore := TStoreRegistry.Create();
    Result := objStore.IsKeyExist(ROOM_ROOT_PATH);
    objStore.Destroy();
  end;

end.
